part of trober_sdk.api;

class DefaultApi {
  final DefaultApiDelegate apiDelegate;
  DefaultApi(ApiClient apiClient) : apiDelegate = DefaultApiDelegate(apiClient);

  /// Get supported App info
  ///
  /// Get supported App info
  Future<AppInfo> appinfoGet({Options? options}) async {
    final response = await apiDelegate.appinfoGet(
      options: options,
    );

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.appinfoGet_decode(body);
  }

  /// Get supported App info
  ///
  /// Get supported App info
  /// List all Carriers
  ///
  /// List all Carriers
  Future<List<Carrier>> carriersGet(
      {Options? options,
      String? tenantId,
      String? name,
      int? page,
      CarrierType? type}) async {
    final response = await apiDelegate.carriersGet(
        options: options,
        tenantId: tenantId,
        name: name,
        page: page,
        type: type);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.carriersGet_decode(body);
  }

  /// List all Carriers
  ///
  /// List all Carriers
  /// Get carrier details
  ///
  /// Get carrier details
  Future<Carrier> carriersIdGet(String id,
      {Options? options, String? tenantId}) async {
    final response = await apiDelegate.carriersIdGet(id,
        options: options, tenantId: tenantId);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.carriersIdGet_decode(body);
  }

  /// Get carrier details
  ///
  /// Get carrier details
  /// Update an existing carrier
  ///
  /// Update an existing carrier
  Future<Carrier> carriersIdPut(String id,
      {Options? options, Carrier? carrier}) async {
    final response =
        await apiDelegate.carriersIdPut(id, options: options, carrier: carrier);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.carriersIdPut_decode(body);
  }

  /// Update an existing carrier
  ///
  /// Update an existing carrier
  /// Create a new Carrier
  ///
  /// Create a new Carrier
  Future<Carrier> carriersPost({Options? options, Carrier? carrier}) async {
    final response =
        await apiDelegate.carriersPost(options: options, carrier: carrier);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.carriersPost_decode(body);
  }

  /// Create a new Carrier
  ///
  /// Create a new Carrier
  /// List all Customers
  ///
  /// List all Customers
  Future<List<Customer>> customersGet(
      {Options? options, String? tenantId, String? name, int? page}) async {
    final response = await apiDelegate.customersGet(
        options: options, tenantId: tenantId, name: name, page: page);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.customersGet_decode(body);
  }

  /// List all Customers
  ///
  /// List all Customers
  /// Get customer details
  ///
  /// Get customer details
  Future<Customer> customersIdGet(String id,
      {Options? options, String? tenantId}) async {
    final response = await apiDelegate.customersIdGet(id,
        options: options, tenantId: tenantId);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.customersIdGet_decode(body);
  }

  /// Get customer details
  ///
  /// Get customer details
  /// Update an existing customer
  ///
  /// Update an existing customer
  Future<Customer> customersIdPut(String id,
      {Options? options, Customer? customer}) async {
    final response = await apiDelegate.customersIdPut(id,
        options: options, customer: customer);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.customersIdPut_decode(body);
  }

  /// Update an existing customer
  ///
  /// Update an existing customer
  /// Create a new Customer
  ///
  /// Create a new Customer
  Future<Customer> customersPost({Options? options, Customer? customer}) async {
    final response =
        await apiDelegate.customersPost(options: options, customer: customer);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.customersPost_decode(body);
  }

  /// Create a new Customer
  ///
  /// Create a new Customer
  /// Get server health
  ///
  /// Get server health status
  Future<void> healthGet({Options? options}) async {
    final response = await apiDelegate.healthGet(
      options: options,
    );

    if (![200].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    if (response.statusCode == 204) {
      return;
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    throw ApiException(500, 'Invalid response received for 204 based API');
  }

  /// Get server health
  ///
  /// Get server health status
  /// List all Orders
  ///
  /// List all Orders
  Future<List<Order>> ordersGet(
      {Options? options,
      String? tenantId,
      int? page,
      String? customerId,
      String? serialNumber,
      OrderStatus? status}) async {
    final response = await apiDelegate.ordersGet(
        options: options,
        tenantId: tenantId,
        page: page,
        customerId: customerId,
        serialNumber: serialNumber,
        status: status);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.ordersGet_decode(body);
  }

  /// List all Orders
  ///
  /// List all Orders
  /// Get order details
  ///
  /// Get order details
  Future<Order> ordersIdGet(String id,
      {Options? options, String? tenantId}) async {
    final response =
        await apiDelegate.ordersIdGet(id, options: options, tenantId: tenantId);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.ordersIdGet_decode(body);
  }

  /// Get order details
  ///
  /// Get order details
  /// Update an existing order
  ///
  /// Update an existing order
  Future<Order> ordersIdPut(String id, {Options? options, Order? order}) async {
    final response =
        await apiDelegate.ordersIdPut(id, options: options, order: order);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.ordersIdPut_decode(body);
  }

  /// Update an existing order
  ///
  /// Update an existing order
  /// Create a new Order
  ///
  /// Create a new Order
  Future<Order> ordersPost({Options? options, Order? order}) async {
    final response =
        await apiDelegate.ordersPost(options: options, order: order);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.ordersPost_decode(body);
  }

  /// Create a new Order
  ///
  /// Create a new Order
  /// Register the device for the user
  ///
  /// Register the device for the user
  Future<void> selfDeviceRegisterPost(
      {Options? options, DeviceId? deviceId}) async {
    final response = await apiDelegate.selfDeviceRegisterPost(
        options: options, deviceId: deviceId);

    if (![204, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    if (response.statusCode == 204) {
      return;
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    throw ApiException(500, 'Invalid response received for 204 based API');
  }

  /// Register the device for the user
  ///
  /// Register the device for the user
  /// Remove the device for the user
  ///
  /// Remove the device for the user
  Future<void> selfDeviceRemovePost(
      {Options? options, DeviceId? deviceId}) async {
    final response = await apiDelegate.selfDeviceRemovePost(
        options: options, deviceId: deviceId);

    if (![204, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    if (response.statusCode == 204) {
      return;
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    throw ApiException(500, 'Invalid response received for 204 based API');
  }

  /// Remove the device for the user
  ///
  /// Remove the device for the user
  /// Get details of the logged in user
  ///
  /// Get details of the logged in user
  Future<User> selfGet({Options? options}) async {
    final response = await apiDelegate.selfGet(
      options: options,
    );

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.selfGet_decode(body);
  }

  /// Get details of the logged in user
  ///
  /// Get details of the logged in user
  /// Get tenant details of the logged in user
  ///
  /// Get tenant details of the logged in user
  Future<Tenant> selfTenantGet({Options? options}) async {
    final response = await apiDelegate.selfTenantGet(
      options: options,
    );

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.selfTenantGet_decode(body);
  }

  /// Get tenant details of the logged in user
  ///
  /// Get tenant details of the logged in user
  /// List all Shipments
  ///
  /// List all Shipments
  Future<List<Shipment>> shipmentsGet(
      {Options? options,
      String? tenantId,
      String? orderId,
      String? carrierId,
      int? page,
      String? driverId,
      String? serialNumber,
      ShipmentType? type,
      ShipmentStatus? status,
      ShipmentSize? size}) async {
    final response = await apiDelegate.shipmentsGet(
        options: options,
        tenantId: tenantId,
        orderId: orderId,
        carrierId: carrierId,
        page: page,
        driverId: driverId,
        serialNumber: serialNumber,
        type: type,
        status: status,
        size: size);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.shipmentsGet_decode(body);
  }

  /// List all Shipments
  ///
  /// List all Shipments
  /// Get shipment details
  ///
  /// Get shipment details
  Future<Shipment> shipmentsIdGet(String id,
      {Options? options, String? tenantId}) async {
    final response = await apiDelegate.shipmentsIdGet(id,
        options: options, tenantId: tenantId);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.shipmentsIdGet_decode(body);
  }

  /// Get shipment details
  ///
  /// Get shipment details
  /// Update an existing shipment
  ///
  /// Update an existing shipment
  Future<Shipment> shipmentsIdPut(String id,
      {Options? options, Shipment? shipment}) async {
    final response = await apiDelegate.shipmentsIdPut(id,
        options: options, shipment: shipment);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.shipmentsIdPut_decode(body);
  }

  /// Update an existing shipment
  ///
  /// Update an existing shipment
  /// Create a new Shipment
  ///
  /// Create a new Shipment
  Future<Shipment> shipmentsPost({Options? options, Shipment? shipment}) async {
    final response =
        await apiDelegate.shipmentsPost(options: options, shipment: shipment);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.shipmentsPost_decode(body);
  }

  /// Create a new Shipment
  ///
  /// Create a new Shipment
  /// List all tenants
  ///
  /// List all tenants
  Future<List<Tenant>> tenantsGet(
      {Options? options, String? name, int? page, TenantType? type}) async {
    final response = await apiDelegate.tenantsGet(
        options: options, name: name, page: page, type: type);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.tenantsGet_decode(body);
  }

  /// List all tenants
  ///
  /// List all tenants
  /// Get tenant details
  ///
  /// Get tenant details
  Future<Tenant> tenantsIdGet(String id, {Options? options}) async {
    final response = await apiDelegate.tenantsIdGet(
      id,
      options: options,
    );

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.tenantsIdGet_decode(body);
  }

  /// Get tenant details
  ///
  /// Get tenant details
  /// Update an existing tenant
  ///
  /// Update an existing tenant
  Future<Tenant> tenantsIdPut(String id,
      {Options? options, Tenant? tenant}) async {
    final response =
        await apiDelegate.tenantsIdPut(id, options: options, tenant: tenant);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.tenantsIdPut_decode(body);
  }

  /// Update an existing tenant
  ///
  /// Update an existing tenant
  /// Create a new tenant
  ///
  /// Create a new tenant
  Future<Tenant> tenantsPost({Options? options, Tenant? tenant}) async {
    final response =
        await apiDelegate.tenantsPost(options: options, tenant: tenant);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.tenantsPost_decode(body);
  }

  /// Create a new tenant
  ///
  /// Create a new tenant
  /// List all Terminals
  ///
  /// List all Terminals
  Future<List<Terminal>> terminalsGet(
      {Options? options,
      String? tenantId,
      int? page,
      String? name,
      TerminalType? type}) async {
    final response = await apiDelegate.terminalsGet(
        options: options,
        tenantId: tenantId,
        page: page,
        name: name,
        type: type);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.terminalsGet_decode(body);
  }

  /// List all Terminals
  ///
  /// List all Terminals
  /// Get terminal details
  ///
  /// Get terminal details
  Future<Terminal> terminalsIdGet(String id,
      {Options? options, String? tenantId}) async {
    final response = await apiDelegate.terminalsIdGet(id,
        options: options, tenantId: tenantId);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.terminalsIdGet_decode(body);
  }

  /// Get terminal details
  ///
  /// Get terminal details
  /// Update an existing terminal
  ///
  /// Update an existing terminal
  Future<Terminal> terminalsIdPut(String id,
      {Options? options, Terminal? terminal}) async {
    final response = await apiDelegate.terminalsIdPut(id,
        options: options, terminal: terminal);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.terminalsIdPut_decode(body);
  }

  /// Update an existing terminal
  ///
  /// Update an existing terminal
  /// Create a new Terminal
  ///
  /// Create a new Terminal
  Future<Terminal> terminalsPost({Options? options, Terminal? terminal}) async {
    final response =
        await apiDelegate.terminalsPost(options: options, terminal: terminal);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.terminalsPost_decode(body);
  }

  /// Create a new Terminal
  ///
  /// Create a new Terminal
  /// List all users
  ///
  /// List all users
  Future<List<User>> usersGet(
      {Options? options,
      String? tenantId,
      int? page,
      String? name,
      UserRole? role}) async {
    final response = await apiDelegate.usersGet(
        options: options,
        tenantId: tenantId,
        page: page,
        name: name,
        role: role);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.usersGet_decode(body);
  }

  /// List all users
  ///
  /// List all users
  /// Delete the user
  ///
  /// Delete the user
  Future<void> usersIdDelete(String id, {Options? options}) async {
    final response = await apiDelegate.usersIdDelete(
      id,
      options: options,
    );

    if (![204, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    if (response.statusCode == 204) {
      return;
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    throw ApiException(500, 'Invalid response received for 204 based API');
  }

  /// Delete the user
  ///
  /// Delete the user
  /// Get user details
  ///
  /// Get user details
  Future<User> usersIdGet(String id,
      {Options? options, String? tenantId}) async {
    final response =
        await apiDelegate.usersIdGet(id, options: options, tenantId: tenantId);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.usersIdGet_decode(body);
  }

  /// Get user details
  ///
  /// Get user details
  /// Update an existing user
  ///
  /// Update an existing user
  Future<User> usersIdPut(String id, {Options? options, User? user}) async {
    final response =
        await apiDelegate.usersIdPut(id, options: options, user: user);

    if (![200, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.usersIdPut_decode(body);
  }

  /// Update an existing user
  ///
  /// Update an existing user
  /// Create a new user
  ///
  /// Create a new user
  Future<User> usersPost({Options? options, User? user}) async {
    final response = await apiDelegate.usersPost(options: options, user: user);

    if (![201, 0].contains(response.statusCode)) {
      throw ApiException(500,
          'Invalid response code ${response.statusCode} returned from API');
    }

    final body = response.body;
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode,
          body == null ? null : await decodeBodyBytes(body));
    }

    if (body == null) {
      throw ApiException(500, 'Received an empty body');
    }

    return await apiDelegate.usersPost_decode(body);
  }

  /// Create a new user
  ///
  /// Create a new user
}

class DefaultApiDelegate {
  final ApiClient apiClient;

  DefaultApiDelegate(this.apiClient);

  Future<ApiResponse> appinfoGet({Options? options}) async {
    // create path and map variables
    final __path = '/appinfo';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<AppInfo> appinfoGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'AppInfo') as AppInfo;
  }

  Future<ApiResponse> carriersGet(
      {Options? options,
      String? tenantId,
      String? name,
      int? page,
      CarrierType? type}) async {
    // create path and map variables
    final __path = '/carriers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<Carrier>> carriersGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<Carrier>') as List)
        .map((item) => item as Carrier)
        .toList();
  }

  Future<ApiResponse> carriersIdGet(String id,
      {Options? options, String? tenantId}) async {
    // create path and map variables
    final __path = '/carriers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Carrier> carriersIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Carrier') as Carrier;
  }

  Future<ApiResponse> carriersIdPut(String id,
      {Options? options, Carrier? carrier}) async {
    Object? postBody = carrier;

    // create path and map variables
    final __path = '/carriers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Carrier') as Carrier;
  }

  Future<ApiResponse> carriersPost({Options? options, Carrier? carrier}) async {
    Object? postBody = carrier;

    // create path and map variables
    final __path = '/carriers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Carrier') as Carrier;
  }

  Future<ApiResponse> customersGet(
      {Options? options, String? tenantId, String? name, int? page}) async {
    // create path and map variables
    final __path = '/customers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<Customer>> customersGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<Customer>') as List)
        .map((item) => item as Customer)
        .toList();
  }

  Future<ApiResponse> customersIdGet(String id,
      {Options? options, String? tenantId}) async {
    // create path and map variables
    final __path =
        '/customers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Customer> customersIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Customer') as Customer;
  }

  Future<ApiResponse> customersIdPut(String id,
      {Options? options, Customer? customer}) async {
    Object? postBody = customer;

    // create path and map variables
    final __path =
        '/customers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Customer') as Customer;
  }

  Future<ApiResponse> customersPost(
      {Options? options, Customer? customer}) async {
    Object? postBody = customer;

    // create path and map variables
    final __path = '/customers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Customer') as Customer;
  }

  Future<ApiResponse> healthGet({Options? options}) async {
    // create path and map variables
    final __path = '/health';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>[];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<void> healthGet_decode(Stream<List<int>> body) async {}
  Future<ApiResponse> ordersGet(
      {Options? options,
      String? tenantId,
      int? page,
      String? customerId,
      String? serialNumber,
      OrderStatus? status}) async {
    // create path and map variables
    final __path = '/orders';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (customerId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'customer_id', customerId));
    }
    if (serialNumber != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'serial_number', serialNumber));
    }
    if (status != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'status', status));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<Order>> ordersGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<Order>') as List)
        .map((item) => item as Order)
        .toList();
  }

  Future<ApiResponse> ordersIdGet(String id,
      {Options? options, String? tenantId}) async {
    // create path and map variables
    final __path = '/orders/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Order> ordersIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Order') as Order;
  }

  Future<ApiResponse> ordersIdPut(String id,
      {Options? options, Order? order}) async {
    Object? postBody = order;

    // create path and map variables
    final __path = '/orders/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Order') as Order;
  }

  Future<ApiResponse> ordersPost({Options? options, Order? order}) async {
    Object? postBody = order;

    // create path and map variables
    final __path = '/orders';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Order') as Order;
  }

  Future<ApiResponse> selfDeviceRegisterPost(
      {Options? options, DeviceId? deviceId}) async {
    Object? postBody = deviceId;

    // create path and map variables
    final __path = '/self/device-register';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<void> selfDeviceRegisterPost_decode(Stream<List<int>> body) async {}
  Future<ApiResponse> selfDeviceRemovePost(
      {Options? options, DeviceId? deviceId}) async {
    Object? postBody = deviceId;

    // create path and map variables
    final __path = '/self/device-remove';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<void> selfDeviceRemovePost_decode(Stream<List<int>> body) async {}
  Future<ApiResponse> selfGet({Options? options}) async {
    // create path and map variables
    final __path = '/self';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<User> selfGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'User') as User;
  }

  Future<ApiResponse> selfTenantGet({Options? options}) async {
    // create path and map variables
    final __path = '/self/tenant';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Tenant> selfTenantGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Tenant') as Tenant;
  }

  Future<ApiResponse> shipmentsGet(
      {Options? options,
      String? tenantId,
      String? orderId,
      String? carrierId,
      int? page,
      String? driverId,
      String? serialNumber,
      ShipmentType? type,
      ShipmentStatus? status,
      ShipmentSize? size}) async {
    // create path and map variables
    final __path = '/shipments';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (orderId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'order_id', orderId));
    }
    if (carrierId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'carrier_id', carrierId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (driverId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'driver_id', driverId));
    }
    if (serialNumber != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'serial_number', serialNumber));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }
    if (status != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'status', status));
    }
    if (size != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'size', size));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<Shipment>> shipmentsGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<Shipment>') as List)
        .map((item) => item as Shipment)
        .toList();
  }

  Future<ApiResponse> shipmentsIdGet(String id,
      {Options? options, String? tenantId}) async {
    // create path and map variables
    final __path =
        '/shipments/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Shipment> shipmentsIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Shipment') as Shipment;
  }

  Future<ApiResponse> shipmentsIdPut(String id,
      {Options? options, Shipment? shipment}) async {
    Object? postBody = shipment;

    // create path and map variables
    final __path =
        '/shipments/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Shipment> shipmentsIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Shipment') as Shipment;
  }

  Future<ApiResponse> shipmentsPost(
      {Options? options, Shipment? shipment}) async {
    Object? postBody = shipment;

    // create path and map variables
    final __path = '/shipments';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Shipment> shipmentsPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Shipment') as Shipment;
  }

  Future<ApiResponse> tenantsGet(
      {Options? options, String? name, int? page, TenantType? type}) async {
    // create path and map variables
    final __path = '/tenants';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<Tenant>> tenantsGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<Tenant>') as List)
        .map((item) => item as Tenant)
        .toList();
  }

  Future<ApiResponse> tenantsIdGet(String id, {Options? options}) async {
    // create path and map variables
    final __path = '/tenants/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Tenant> tenantsIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Tenant') as Tenant;
  }

  Future<ApiResponse> tenantsIdPut(String id,
      {Options? options, Tenant? tenant}) async {
    Object? postBody = tenant;

    // create path and map variables
    final __path = '/tenants/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Tenant') as Tenant;
  }

  Future<ApiResponse> tenantsPost({Options? options, Tenant? tenant}) async {
    Object? postBody = tenant;

    // create path and map variables
    final __path = '/tenants';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Tenant') as Tenant;
  }

  Future<ApiResponse> terminalsGet(
      {Options? options,
      String? tenantId,
      int? page,
      String? name,
      TerminalType? type}) async {
    // create path and map variables
    final __path = '/terminals';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (type != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'type', type));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<Terminal>> terminalsGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<Terminal>') as List)
        .map((item) => item as Terminal)
        .toList();
  }

  Future<ApiResponse> terminalsIdGet(String id,
      {Options? options, String? tenantId}) async {
    // create path and map variables
    final __path =
        '/terminals/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<Terminal> terminalsIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Terminal') as Terminal;
  }

  Future<ApiResponse> terminalsIdPut(String id,
      {Options? options, Terminal? terminal}) async {
    Object? postBody = terminal;

    // create path and map variables
    final __path =
        '/terminals/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Terminal') as Terminal;
  }

  Future<ApiResponse> terminalsPost(
      {Options? options, Terminal? terminal}) async {
    Object? postBody = terminal;

    // create path and map variables
    final __path = '/terminals';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'Terminal') as Terminal;
  }

  Future<ApiResponse> usersGet(
      {Options? options,
      String? tenantId,
      int? page,
      String? name,
      UserRole? role}) async {
    // create path and map variables
    final __path = '/users';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }
    if (page != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'page', page));
    }
    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (role != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'role', role));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<List<User>> usersGet_decode(Stream<List<int>> body) async {
    return (LocalApiClient.deserializeFromString(
            await utf8.decodeStream(body), 'List<User>') as List)
        .map((item) => item as User)
        .toList();
  }

  Future<ApiResponse> usersIdDelete(String id, {Options? options}) async {
    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'DELETE';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<void> usersIdDelete_decode(Stream<List<int>> body) async {}
  Future<ApiResponse> usersIdGet(String id,
      {Options? options, String? tenantId}) async {
    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (tenantId != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'tenant_id', tenantId));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(__path, queryParams, null, authNames, opt);
  }

  Future<User> usersIdGet_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'User') as User;
  }

  Future<ApiResponse> usersIdPut(String id,
      {Options? options, User? user}) async {
    Object? postBody = user;

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'PUT';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersIdPut_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'User') as User;
  }

  Future<ApiResponse> usersPost({Options? options, User? user}) async {
    Object? postBody = user;

    // create path and map variables
    final __path = '/users';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    postBody = postBody == null ? null : LocalApiClient.serialize(postBody);

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersPost_decode(Stream<List<int>> body) async {
    return LocalApiClient.deserializeFromString(
        await utf8.decodeStream(body), 'User') as User;
  }
}
